@@ -168,7 +168,8 @@ double ptToDouble(const bt::ptime & pt, const bool asDate=false) {
     // contain the additional DST adjustment
     double totsec = tdiff.total_microseconds()/1.0e6, dstadj = 0;
 #if defined(_WIN32)
-    if (totsec > 0) {           // on Windows, for dates before 1970-01-01: segfault
+    if (totsec > 0  &&                  // on Windows before 1970-01-01: segfault
+       localAsTm->tm_year < 1100) {     // tm_year is year-1900, so year 3000 is it
         dstadj = localAsTm->tm_isdst*60*60;
     }
 #else
@@ -316,7 +317,9 @@ double r_stringToTime(const std::string s, const std::string tz,
     // loop over formats and try them til one fits
     for (size_t i=0; !done && i < nrformats; ++i) {
         // asPOSIXct and Rstrptime are both from RApiDatetime
-        res = Rcpp::as<double>( asPOSIXct( Rstrptime(ss, Rcpp::wrap(rformats[i]), tzs) , tzs) );
+        Rcpp::Shield<SEXP> sp(Rstrptime(ss, Rcpp::wrap(rformats[i]), tzs));
+        Rcpp::Shield<SEXP> ct(asPOSIXct(sp, tzs));;
+        res = Rcpp::as<double>(ct);
         done = ! Rcpp::traits::is_na<REALSXP>(res);
     }
     return res;
@@ -437,7 +440,7 @@ Rcpp::NumericVector anytime_cpp(SEXP x,
     } else if (Rcpp::is<Rcpp::NumericVector>(x) && asDate && REAL(x)[0] <= maxIntAsDate) {
         // if numeric and below date cutoff, treat as (already numeric/int) date
         // we clone first to ensure input is preserved
-        Rcpp::NumericVector z = Rcpp::clone(x);
+        Rcpp::NumericVector z(Rcpp::Shield<SEXP>(Rcpp::clone(x)));
         return Rcpp::DateVector(z);
 
     } else if (Rcpp::is<Rcpp::IntegerVector>(x) && asDate && INTEGER(x)[0] <= maxIntAsDate) {
@@ -460,7 +463,7 @@ Rcpp::NumericVector anytime_cpp(SEXP x,
         // now we actually should have a proper large numeric (ie as.numeric(Sys.time())
         // so we can simply return as the already created Datetime vector
         // we clone first to ensure input is preserved
-        Rcpp::NumericVector z = Rcpp::clone(x);
+        Rcpp::NumericVector z(Rcpp::Shield<SEXP>(Rcpp::clone(x)));
         return Rcpp::DatetimeVector(z, asUTC ? "UTC" : tz.c_str());
 
     } else if (Rcpp::is<Rcpp::IntegerVector>(x)) {
